@@ -14,6 +14,7 @@ import boto3
 import botocore
 import tqdm
 import subprocess
+import platform
 class NativeMethods(object):
     def __init__(
         self,
@@ -48,7 +49,10 @@ class NativeMethods(object):
     def _check_and_download_files(self, system_os):
         required_files=[]
         if system_os == "Linux":
-            required_files=["lib_fhe.so","libtensorflow-lite.so"]
+            if platform.machine() in ["aarch64","arm"]:
+                required_files=["lib_fhe_arm64.so","libtensorflow-lite-arm64.so"]
+            else:
+                required_files=["lib_fhe.so","libtensorflow-lite.so"]
         elif system_os == "Windows":
             required_files=[]
         elif system_os == "Darwin":
@@ -78,10 +82,16 @@ class NativeMethods(object):
                     bar.update(len(chunk))
 
     def _load_linux_libraries(self):
-        self._library_path = str(self._local_lib_path.joinpath("lib_fhe.so").resolve())
-        self._library_path_2 = str(self._local_lib_path.joinpath("libtensorflow-lite.so").resolve())
-        ctypes.CDLL(self._library_path_2, mode=1)
-        self._spl_so_face = ctypes.CDLL(self._library_path)
+        if platform.machine() in ["aarch64","arm"]:
+                self._library_path = str(self._local_lib_path.joinpath("lib_fhe_arm64.so").resolve())
+                self._library_path_2 = str(self._local_lib_path.joinpath("libtensorflow-lite-arm64.so").resolve())
+                ctypes.CDLL(self._library_path_2, mode=1)
+                self._spl_so_face = ctypes.CDLL(self._library_path)
+        else:
+                self._library_path = str(self._local_lib_path.joinpath("lib_fhe.so").resolve())
+                self._library_path_2 = str(self._local_lib_path.joinpath("libtensorflow-lite.so").resolve())
+                ctypes.CDLL(self._library_path_2, mode=1)
+                self._spl_so_face = ctypes.CDLL(self._library_path)
 
     def _load_windows_libraries(self):
         self._library_path = str(self._local_lib_path.joinpath("privid_fhe.dll").resolve())
@@ -167,7 +177,9 @@ class NativeMethods(object):
                 "collection_a": named_urls("FACE3_1"),
                 "collection_b": named_urls("FACE3_2"),
                 "collection_c": named_urls("FACE3_3"),
-                "collection_d": named_urls("FACE3_4")
+                "collection_d": named_urls("FACE3_4"),
+                "collection_e": named_urls("FACE4_1"),
+                "collection_f": named_urls("FACE4_2"),
             },
             "session_token": self._api_key_string,
             "debug_level": self._logging_level.value,
@@ -671,7 +683,7 @@ class NativeMethods(object):
             )
             p_buffer_result = c_char_p()
             p_buffer_result_length = c_int()
-            config_object_default = {"face_thresholds_rem_bad_emb_default": 1.275, "face_thresholds_med": 1.275,"conf_score_thr_enroll":0.2}
+            config_object_default = {"face_thresholds_rem_bad_emb_default": 1.24, "face_thresholds_med": 1.24,"conf_score_thr_enroll":0.2}
 
             if config_object and hasattr(config_object, 'get_config_param') and config_object.get_config_param():
                 config_param_str = config_object.get_config_param()
